==> workrave_1.9.3.orig.tar.gz: workrave-1.9.3/frontend/common/include/credits.h <==
/*
 * credits.h --- Workrave credits
 *
 * Copyright (C) 2007, 2008, 2009, 2010 Rob Caelers <robc@krandor.nl>
 * All rights reserved.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef CREDITS_H
#define CREDITS_H

#include <stdlib.h>

const char *workrave_copyright =
  "Copyright 2001-2010 Rob Caelers & Raymond Penners";

const char *workrave_authors[] = {
  "Developers:",
  "Rob Caelers <robc@krandor.org>",
  "Raymond Penners <raymond@dotsphinx.com>",
  "Ray Satiro <raysatiro@yahoo.com>",
  "",
  "Sounds:",
  "Ruairi Fullam",
  NULL
};

const char *workrave_translators =
 /* bg */           "Иван Димов <idimov@users.sourceforge.net>\n"
 /* ca */           "Jordi Mallach <jordi@sindominio.net>\n"
 /* cs */           "Juraj Kubelka <Juraj.Kubelka@email.cz>\n"
 /* de */           "Johannes Rohr <j.rohr@comlink.apc.org>\n"
 /* dk */           "Christian Vejlbo <christian@vejlbo.dk>\n"
 /* el */           "Prokopis Prokopidis <prokopidis@gmail.com>\n"
 /* eo */           "Eric lesh <eclesh@pacbell.net>\n"
 /* es */           "Pablo Rodriguez <ousia@gmx.net>\n"
 /* et */           "Marko Väljaots <aatomik@hotmail.com>\n"
 /* fr 1 */         "Thomas Basset <thomas.basset@netcourrier.com>\n"
 /* fr 2 */         "Benjamin Siband <translations@wordinfrench.com>\n"
 /* he */           "Haggai Eran <he3@bezeqint.net>\n"
 /* hu-1 */         "ORY Mate <orymate@gmail.com>\n"
 /* hu-2 */         "Gabor Kelemen <kelemeng@gnome.hu>\n"
 /* ga */           "Seanán Ó Coistín <seananoc@gmail.com>\n"
 /* it */           "Eraldo Girardi <eraldster@katamail.com>\n"
 /* ja */           "Masanobu Yokota <masanobu.yokota@nifty.com>\n"
 /* ko */           "김재용 <nawane@naver.com>\n"
 /* lt */           "Artūras Šlajus <x11@h2o.sky.lt>\n"
 /* nl */           "Raymond Penners <raymond@dotsphinx.com>\n"
 /* no */           "Morten Lunde <morten.lunde@broadpark.no>\n"
 /* pl */           "Mikolaj Machowski <mikmach@wp.pl>\n"
 /* pt_BR -1 */     "Claudio Ferreira Filho <filhocf@yahoo.com.br>\n"
 /* ro */           "Alexandru Szasz <alexxed@gmail.com>\n"
 /* ru */           "Sergey Kirkinsky <ksa@pfr.altai.ru>\n"
 /* sk */           "Peter Tuharsky <Peter.Tuharsky@banskabystrica.sk>\n"
 /* sl */           "Vanja Cvelbar <cvelbar@gmail.com>\n"
 /* sv */           "Daniel Nylander <info@danielnylander.se>\n"
 /* tr */           "Enver ALTIN <ealtin@parkyeri.com>\n"
 /* zh_CN */        "Tao WEI <weitao1979@gmail.com>\n"
 /* zh_TW */        "Rex Tsai <chihchun@linux.org.tw>\n";

#endif /* CREDITS_H */

==> workrave_1.9.4.orig.tar.gz: workrave-1.9.4/frontend/common/include/credits.h <==
/*
 * credits.h --- Workrave credits
 *
 * Copyright (C) 2007, 2008, 2009, 2010, 2011 Rob Caelers <robc@krandor.nl>
 * All rights reserved.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef CREDITS_H
#define CREDITS_H

#include <stdlib.h>

const char *workrave_copyright =
  "Copyright 2001-2010 Rob Caelers & Raymond Penners";

const char *workrave_authors[] = {
  "Developers:",
  "Rob Caelers <robc@krandor.org>",
  "Raymond Penners <raymond@dotsphinx.com>",
  "Ray Satiro <raysatiro@yahoo.com>",
  "",
  "Sounds:",
  "Ruairi Fullam",
  NULL
};

const char *workrave_translators =
 /* bg */           "Иван Димов <idimov@users.sourceforge.net>\n"
 /* ca */           "Jordi Mallach <jordi@sindominio.net>\n"
 /* cs */           "Juraj Kubelka <Juraj.Kubelka@email.cz>\n"
 /* de */           "Johannes Rohr <j.rohr@comlink.apc.org>\n"
 /* dk */           "Christian Vejlbo <christian@vejlbo.dk>\n"
 /* el */           "Prokopis Prokopidis <prokopidis@gmail.com>\n"
 /* eo */           "Eric lesh <eclesh@pacbell.net>\n"
 /* es */           "Pablo Rodriguez <ousia@gmx.net>\n"
 /* et */           "Marko Väljaots <aatomik@hotmail.com>\n"
 /* fr 1 */         "Thomas Basset <thomas.basset@netcourrier.com>\n"
 /* fr 2 */         "Benjamin Siband <translations@wordinfrench.com>\n"
 /* he */           "Haggai Eran <he3@bezeqint.net>\n"
 /* hu-1 */         "ORY Mate <orymate@gmail.com>\n"
 /* hu-2 */         "Gabor Kelemen <kelemeng@gnome.hu>\n"
 /* ga */           "Seanán Ó Coistín <seananoc@gmail.com>\n"
 /* it */           "Eraldo Girardi <eraldster@katamail.com>\n"
 /* ja */           "Masanobu Yokota <masanobu.yokota@nifty.com>\n"
 /* ko */           "김재용 <nawane@naver.com>\n"
 /* lt */           "Artūras Šlajus <x11@h2o.sky.lt>\n"
 /* nl */           "Raymond Penners <raymond@dotsphinx.com>\n"
 /* no */           "Morten Lunde <morten.lunde@broadpark.no>\n"
 /* pl */           "Mikolaj Machowski <mikmach@wp.pl>\n"
 /* pt_BR -1 */     "Claudio Ferreira Filho <filhocf@yahoo.com.br>\n"
 /* ro */           "Alexandru Szasz <alexxed@gmail.com>\n"
 /* ru */           "Sergey Kirkinsky <ksa@pfr.altai.ru>\n"
 /* sk */           "Peter Tuharsky <Peter.Tuharsky@banskabystrica.sk>\n"
 /* sl */           "Vanja Cvelbar <cvelbar@gmail.com>\n"
 /* sv */           "Daniel Nylander <info@danielnylander.se>\n"
 /* tr */           "Enver ALTIN <ealtin@parkyeri.com>\n"
 /* zh_CN */        "Tao WEI <weitao1979@gmail.com>\n"
 /* zh_TW */        "Rex Tsai <chihchun@linux.org.tw>\n"
 /* zh_TW */        "Daniel YC Lin (林原志) <dlin.tw@gmail.com>>\n";

#endif /* CREDITS_H */
